# vim:ts=4
#
# Copyright (c) 2002-2010 Hypertriton, Inc. <http://hypertriton.com/>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE FOR
# ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
# USE OF THIS SOFTWARE EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

my $testCode = << 'EOF';
#include <ft2build.h>
#include FT_FREETYPE_H
#include FT_OUTLINE_H
int
main(int argc, char *argv[])
{
	FT_Library library;
	FT_Face face;
	FT_Init_FreeType(&library);
	FT_New_Face(library, "foo", 0, &face);
	return (0);
}
EOF

sub Test
{
	my ($ver, $pfx) = @_;

	MkExecOutputPfx($pfx, 'freetype-config', '--version', 'FREETYPE_VERSION');
	MkExecOutputPfx($pfx, 'freetype-config', '--cflags', 'FREETYPE_CFLAGS');
	MkExecOutputPfx($pfx, 'freetype-config', '--libs', 'FREETYPE_LIBS');
	
	MkCaseIn('${host}');
	MkCaseBegin('*-*-irix*');
		MkIfExists('/usr/freeware/include');
			MkAppend('FREETYPE_CFLAGS', '-I/usr/freeware/include');
		MkEndif;
		MkCaseEnd;
	MkEsac;

	MkIfNE('${FREETYPE_VERSION}', '');
		MkFoundVer($pfx, $ver, 'FREETYPE_VERSION');
		MkPrintN('checking whether FreeType works...');
		MkCompileC('HAVE_FREETYPE',
		           '${FREETYPE_CFLAGS}',
				   '${FREETYPE_LIBS}', $testCode);
		MkSaveIfTrue('${HAVE_FREETYPE}', 'FREETYPE_CFLAGS', 'FREETYPE_LIBS');
	MkElse;
		MkNotFound($pfx);
	    MkSaveUndef('HAVE_FREETYPE');
	MkEndif;
	return (0);
}

sub Link
{
	my $lib = shift;

	if ($lib ne 'freetype') {
		return (0);
	}
	PmIfHDefined('HAVE_FREETYPE');
		PmLink('freetype');
		if ($EmulEnv =~ /^cb-/) {
			PmIncludePath('$(#freetype.include)');
			PmLibPath('$(#freetype.lib)');
		}
	PmEndif;
	return (1);
}

sub Emul
{
	my ($os, $osrel, $machine) = @_;

	if ($os eq 'darwin') {
		MkDefine('FREETYPE_CFLAGS', '-I/usr/X11R6/include '.
		                            '-I/usr/X11R6/include/freetype2');
		MkDefine('FREETYPE_LIBS', '-L/usr/X11R6/lib -lfreetype');
	} elsif ($os eq 'windows') {
		MkDefine('FREETYPE_CFLAGS', '');
		MkDefine('FREETYPE_LIBS', 'freetype6');
	} else {
		MkDefine('FREETYPE_CFLAGS', '-I/usr/include/freetype2 '.
		                            '-I/usr/local/include/freetype2 '.
									'-I/usr/local/include '.
									'-I/usr/X11R6/include/freetype2 '.
									'-I/usr/X11R6/include');
		MkDefine('FREETYPE_LIBS', '-L/usr/local/lib '.
		                          '-Wl,--rpath --Wl,/usr/local/lib ' .
		                          '-L/usr/X11R6/lib '.
		                          '-Wl,--rpath --Wl,/usr/X11R6/lib ' .
		                          '-lfreetype -lz');
	}
	MkDefine('HAVE_FREETYPE', 'yes');
	MkSave('HAVE_FREETYPE', 'FREETYPE_CFLAGS', 'FREETYPE_LIBS');
	return (1);
}

BEGIN
{
	$DESCR{'freetype'} = 'FreeType (http://www.freetype.org)';
	$DEPS{'freetype'} = 'cc';
	$TESTS{'freetype'} = \&Test;
	$EMUL{'freetype'} = \&Emul;
	$LINK{'freetype'} = \&Link;
}

;1
